==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/elevator2/dialogs_nl.lua <==

dialogId("zd2-m-dalsi", "font_small", "Another elevator? How many more are there to come?")
dialogStr("Nog een lift? Hoe veel van die dingen hebben ze hier?")


dialogId("zd2-v-odlis0", "font_big", "I can see some differences here... And somehow I don`t think it`s going to be easier.")
dialogStr("Het ziet er hier wel anders uit... En ik vermoed dat het niet makkelijker zal zijn dan de vorige keer.")


dialogId("zd2-v-odlis1", "font_big", "The last one had a little bit more advantageous architecture, I think.")
dialogStr("De vorige had wel een wat handigere constructie, volgens mij.")


dialogId("zd2-v-vlevo", "font_big", "Can you see that thing in the lower left? It must be some ancient religious symbol.")
dialogStr("Zie je dat ding linksonder? Dat is vast een oud religieus symbool ofzo.")


dialogId("zd2-m-nevid0", "font_small", "Fortunately, I can`t see much of it.")
dialogStr("Gelukkig kan ik het niet goed zien.")


dialogId("zd2-m-nevid1", "font_small", "If you are right, I`d rather not know what kind of religion it was.")
dialogStr("Als je gelijkt hebt wil ik liever niet weten wat voor geloof dat was.")


dialogId("zd2-v-symbol", "font_big", "I am afraid that if we use that strange symbol we could unwillingly initiate some dark ritual.")
dialogStr("Ik ben bang dat als we dat rare symbool gebruiken, dat we dan perongeluk duistere krachten zouden kunnen oproepen.")


dialogId("zd2-m-douf", "font_small", "I just hope it won`t drop on my head.")
dialogStr("Ik hoop alleen maar dat het niet op m'n kop zal vallen.")


dialogId("zd2-m-lebka", "font_small", "Another skull. It`s worse than a morgue.")
dialogStr("Nog een schedel. Het lijkt hier wel een lijkenhuis.")


dialogId("zd2-v-haml", "font_big", "It`s worse than Hamlet.")
dialogStr("Het is hier erger dan in Hamlet.")


dialogId("zd2-x-hus0", "font_lightgrey", "Hush, hush!")
dialogStr("Ssst, ssst!")


dialogId("zd2-x-hus1", "font_lightgrey", "Don`t come near!")
dialogStr("Blijf bij me uit de buurt!")


dialogId("zd2-x-kricet", "font_lightgrey", "I`ll scream if you touch me.")
dialogStr("Ik ga gillen als je aan me komt.")


dialogId("zd2-x-krik0", "font_lightgrey", "Aaaaa!")
dialogStr("Aaaaa!")


dialogId("zd2-x-krik1", "font_lightgrey", "Help!")
dialogStr("Help!")


dialogId("zd2-x-ritual", "font_lightgrey", "I`ll initiate a dark ritual!")
dialogStr("Ik ga een duistere kracht oproepen, hoor!")


dialogId("zd2-x-nechteme", "font_lightgrey", "Leave me alone!")
dialogStr("Laat me met rust!")


dialogId("zd2-x-nechme", "font_lightgrey", "Leave me alone and get lost!")
dialogStr("Laat me met rust en rot op!")


dialogId("zd2-x-pokoj", "font_lightgrey", "Cut it out!")
dialogStr("Hou op!")


dialogId("zd2-x-fuj", "font_lightgrey", "Yuck, don`t nibble me!")
dialogStr("Gatver, niet aan mij knabbelen!")


dialogId("zd2-x-necurat", "font_lightgrey", "Don`t think you can pee on me.")
dialogStr("Zet het maar uit je hoofd om op me te plassen.")


dialogId("zd2-x-neklast", "font_lightgrey", "Just forget about laying your spawn here.")
dialogStr("Waag het niet om hier te paaien!")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/elevator2/dialogs_nl.lua <==

dialogId("zd2-m-dalsi", "font_small", "Another elevator? How many more are there to come?")
dialogStr("Nog een lift? Hoeveel van die dingen hebben ze hier?")


dialogId("zd2-v-odlis0", "font_big", "I can see some differences here... And somehow I don’t think it’s going to be easier.")
dialogStr("Het ziet er hier wel anders uit... En ik vermoed dat het niet makkelijker zal zijn dan de vorige keer.")


dialogId("zd2-v-odlis1", "font_big", "The last one had a little bit more advantageous architecture, I think.")
dialogStr("De vorige lift had wel een wat handigere constructie, denk ik.")


dialogId("zd2-v-vlevo", "font_big", "Can you see that thing in the lower left? It must be some ancient religious symbol.")
dialogStr("Zie je dat ding linksonder? Dat is vast een oud religieus symbool ofzo.")


dialogId("zd2-m-nevid0", "font_small", "Fortunately, I can’t see much of it.")
dialogStr("Gelukkig kan ik het niet goed zien.")


dialogId("zd2-m-nevid1", "font_small", "If you are right, I’d rather not know what kind of religion it was.")
dialogStr("Als je gelijkt hebt wil ik liever niet weten wat voor geloof dat was.")


dialogId("zd2-v-symbol", "font_big", "I am afraid that if we use that strange symbol we could unwillingly initiate some dark ritual.")
dialogStr("Ik ben bang dat als we dat rare symbool gebruiken, dat we dan perongeluk duistere krachten zouden kunnen oproepen.")


dialogId("zd2-m-douf", "font_small", "I just hope it won’t drop on my head.")
dialogStr("Ik hoop alleen maar dat het niet op m'n kop zal vallen.")


dialogId("zd2-m-lebka", "font_small", "Another skull. It’s worse than a morgue.")
dialogStr("Nog een schedel. Het lijkt hier wel een mortuarium.")


dialogId("zd2-v-haml", "font_big", "It’s worse than Hamlet.")
dialogStr("Het is hier erger dan in Hamlet.")


dialogId("zd2-x-hus0", "font_lightgrey", "Hush, hush!")
dialogStr("Ssst, ssst!")


dialogId("zd2-x-hus1", "font_lightgrey", "Don’t come near!")
dialogStr("Blijf bij me uit de buurt!")


dialogId("zd2-x-kricet", "font_lightgrey", "I’ll scream if you touch me.")
dialogStr("Ik ga gillen als je aan me komt.")


dialogId("zd2-x-krik0", "font_lightgrey", "Aaaaa!")
dialogStr("Aaaaa!")


dialogId("zd2-x-krik1", "font_lightgrey", "Help!")
dialogStr("Help!")


dialogId("zd2-x-ritual", "font_lightgrey", "I’ll initiate a dark ritual!")
dialogStr("Ik ga een duistere kracht oproepen, hoor!")


dialogId("zd2-x-nechteme", "font_lightgrey", "Leave me alone!")
dialogStr("Laat me met rust!")


dialogId("zd2-x-nechme", "font_lightgrey", "Leave me alone and get lost!")
dialogStr("Laat me met rust en zout op!")


dialogId("zd2-x-pokoj", "font_lightgrey", "Cut it out!")
dialogStr("Hou op!")


dialogId("zd2-x-fuj", "font_lightgrey", "Yuck, don’t nibble me!")
dialogStr("Gatver, niet aan mij knabbelen!")


dialogId("zd2-x-necurat", "font_lightgrey", "Don’t think you can pee on me.")
dialogStr("Zet het maar uit je hoofd om op me te plassen.")


dialogId("zd2-x-neklast", "font_lightgrey", "Just forget about laying your spawn here.")
dialogStr("Waag het niet om hier te paaien!")
